@@ -84,6 +84,7 @@ struct _GdmChooserHost {
 static const gchar *scanning_message = N_("Please wait: scanning local network...");
 static const gchar *empty_network = N_("No serving hosts were found.");
 static const gchar *active_network = N_("Choose a ho_st to connect to:");
+static void gdm_chooser_cancel (/*void*/);
 
 /* XDM chooser style stuff */
 static gchar *xdm_address = NULL;
@@ -91,7 +92,6 @@ static gchar *client_address = NULL;
 static gint connection_type = 0;
 
 /* Exported for glade */
-void gdm_chooser_cancel (/*void*/);
 void gdm_chooser_add_host (void);
 void gdm_chooser_add_entry_changed (void);
 void gdm_chooser_manage (GtkButton *button, gpointer data);
@@ -448,6 +448,14 @@ gdm_chooser_decode_packet (GIOChannel   *source,
     int pipe_buf;
     gboolean host_not_willing = FALSE;
 
+#ifdef PIPE_BUF
+    pipe_buf = PIPE_BUF;
+#else
+    /* apparently Hurd doesn't have PIPE_BUF */
+    pipe_buf = fpathconf (1 /*stdout*/, _PC_PIPE_BUF);
+    /* could return -1 if no limit */
+#endif
+
     if ( ! (condition & G_IO_IN)) 
         return TRUE;
 
@@ -508,7 +516,7 @@ gdm_chooser_decode_packet (GIOChannel   *source,
 
 	    hostname = hbuf;
 
-	    if (strlen (hostname)+1 > PIPE_BUF)
+	    if (strlen (hostname) + 1 > pipe_buf)
 		goto done;
 	    hostname = g_strdup (hostname);
 
@@ -531,7 +539,7 @@ gdm_chooser_decode_packet (GIOChannel   *source,
 				AF_INET);
 
 	    hostname = (he && he->h_name) ? he->h_name : inet_ntoa (clnt_sa.sin_addr);
-	    if (strlen (hostname)+1 > PIPE_BUF)
+	    if (strlen (hostname) + 1 > pipe_buf)
                    goto done;
 
 	    hostname = g_strdup (hostname);
@@ -544,14 +552,6 @@ gdm_chooser_decode_packet (GIOChannel   *source,
         }
     }
 
-#ifdef PIPE_BUF
-    pipe_buf = PIPE_BUF;
-#else
-    /* apparently Hurd doesn't have PIPE_BUF */
-    pipe_buf = fpathconf (1 /*stdout*/, _PC_PIPE_BUF);
-    /* could return -1 if no limit */
-#endif
-
     /* We can't pipe hostnames larger than this */
     if (pipe_buf > 0 && strlen (hostname)+1 > pipe_buf) {
 	    g_free (hostname);
@@ -1535,8 +1535,8 @@ gdm_chooser_add_entry_changed (void)
 	gtk_widget_set_sensitive (add_button, ! ve_string_empty (name));
 }
 
-void
-gdm_chooser_cancel (/*void*/)
+static void
+gdm_chooser_cancel (int sig)
 {
     if (scan_time_handler > 0) {
 	    g_source_remove (scan_time_handler);
@@ -1907,7 +1907,7 @@ GOptionEntry chooser_options [] = {
           N_("Client address to return in response to xdm"), N_("ADDRESS") },
        { "connectionType", '\0', 0, G_OPTION_ARG_INT, &connection_type,
           N_("Connection type to return in response to xdm"), N_("TYPE") },
-       { G_OPTION_REMAINING, NULL, 0, G_OPTION_ARG_STRING_ARRAY, &chooser_hosts,
+       { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &chooser_hosts,
           NULL, NULL },
        { NULL }
  };
